--[[

This file, introduced in EventHorizon v1.6, makes trinkets incredibly easy to handle.
If your trinket is on this list, just add one or both of these to your class config:

-- Top Trinket
self:NewSpell({slotID = 13})

-- Bottom Trinket
self:NewSpell({slotID = 13})

Additional flags that can be used: NOTHING. slotID does NOT play nice with other spell config flags. You can try, but it will just break things. Other than that fact, it's extremely easy to set up an equipment slot. Cooldowns and buffs are tracked as long as EH has the info for them.

Cooldowns:
Visible trinket cooldowns are tracked automatically. No tinkering required.
Internal trinket cooldowns (Equip: procs for the most part) rely on the list below. If your trinket is on the list, you should see the cooldown when it procs. (SHOULD, not WILL - I don't have every trinket on the list, so I can't confirm many of them, but the ones I've tested work perfectly.)

Buffs:
Since trinkets usually don't use buffs of the same name as the trinket itself, EventHorizon is only able to track the trinket buffs listed below. If your trinket is not on the list, bring it to my attention. At the time of the list's initial writing, EPIC ilvl 200+ trinkets with Equip: or Use: BUFFS should be mostly in. Blues haven't been written in. Proc/use effects that aren't buffs are not tracked.



Engineering items can be tracked as well. Gloves are slotID 10, feet are slotID 8. Hyperspeed Accelerators (glove haste buff) and Nitro Boosts (rocket boots) are done for you. Cooldowns are based on the item itself, which is a handy feature of the API that makes things that much more accurate.



Inventory items are a little different, but done in about the same way. You'll need the itemID for these:

-- Saronite Bombs
self:NewSpell({itemID = 41119})

If you need more flags...

-- Saronite Bombs
self:NewSpell({
	itemID = 41119,
	debuff = 12345,
	stance = 9,
})

...etc.

Incompatible flags:
* cooldown - Setting the cooldown flag overrides GetItemCooldown with GetSpellCooldown. Basically, if you add the cooldown flag, you're only getting the item's icon.
* dot - Well, technically it would work, but only if the item has a buff or debuff, and I doubt it would work quite correctly.

Flags that work:
* playerbuff / debuff - These work just fine.
* internalcooldown - Since it works off playerbuff/debuff, setting an ICD may serve as a substitute if you really do want cooldown information for whatever additional spell you're tracking. Not sure if I'd recommend it though.
* auraunit - Affects nothing but playerbuff/debuff, so setting a custom unit to watch is fine.
* cleu/event - Should be fine, though not sure what you'd need it for in this case.
* requiredTalent - Yep, works fine.
* requiredGlyph - Should be fine as well, though talents usually work better (unless you have two mostly identical specs with different glyphs).
* stance/nostance - Should work fine.

Anything not listed, I have no idea. Heck, I haven't even tried most of the ones that ARE listed, I'm just pretty sure they won't horribly break things.



Now, about the big list below.

If your trinket is NOT on the list, as long as it has a Use effect its cooldown WILL still be tracked. Bring the trinket to my attention via the WoWInterface comments page and I'll add its buff for the next release. The initial release of this file contains most ilvl 200+ epic trinkets with Use and Equip effects, with internal cooldowns as applicable.

Some trinkets are exempt from this list due to their complex nature. DMC:Greatness and Death's Choice/Verdict are among them.

Some trinkets on the list may not work correctly. If they don't, let me know.

If you have questions, feel free to ask.

]]--


-- ["ItemName or ItemID"] = spellID or {spellID,internalCooldown}
-- If you need multiple spellids and don't need an internal cooldown, use {{spellID1,spellID2,...},true}
EventHorizon.trinkets = {
	["Corroded Skeleton Key"] = 71586,
	["Corpse Tongue Coin"] = {71639,30},
	["Dislodged Foreign Object"] = {71601,45},
	["Sindragosa's Flawless Fang"] = 71638,
	["Phylactery of the Nameless Lich"] = {71636,45},
	["Muradin's Spyglass"] = 71572,
	["Maghia's Misguided Quill"] = 71579,
	["Herkuml War Token"] = 71396,
	["Purified Lunar Dust"] = 71584,
	["Unidentifiable Organ"] = 71577,
	["Whispering Fanged Skull"] = 71541,
	["Reign of the Dead"] = {67759,2},
	["Reign of the Unliving"] = {67759,2},
	["Juggernaut's Vitality"] = 67753,
	["Satrina's Impeding Scarab"] = 67753,
	["Binding Stone"] = 67740,
	["Binding Light"] = 67740,
	["Eitrigg's Oath"] = 67742,
	["Ferver of the Frostborn"] = 67742,
	["Fetish of Volatile Power"] = 67744,
	["Talisman of Volatile Power"] = 67744,
	["Mark of Supremacy"] = 67695,
	["Glyph of Indomitability"] = 67694,
	["Talisman of Resurgence"] = 67684,
	["Shard of the Crystal Heart"] = 67683,
	["Vengeance of the Forsaken"] = 67747,
	["Victor's Call"] = 67747,
	["Flare of the Heavens"] = {64713,45},
	["Show of Faith"] = {64739,45},
	["Ephemeral Snowflake"] = 71568,
	["Ick's Rotting Thumb"] = 71569,
	["Needle-Encrusted Scorpion"] = {71403,45},
	["Nevermelting Ice Crystal"] = 71563,
	["Heart of Iron"] = 64763,
	["Blood of the Old God"] = 64792,
	["Dark Matter"] = {65024,45},
	["Living Flame"] = 64712,
	["Mark of Norgannon"] = 60319,
	["Meteorite Crystal"] = 64999,
	["Mjolnir Runestone"] = {65019,45},
	["Pandora's Plea"] = {64741,45},
	["Scale of Fates"] = 64707,
	["Sif's Remembrance"] = {65003,45},
	["The General's Heart"] = {64765,45},
	["Wrathstone"] = 64800,
	["Elemental Focus Stone"] = {65004,45},
	["Energy Siphon"] = 65008,
	["Eye of the Broodmother"] = 65506,
	["Furnace Stone"] = 65011,
	["Pyrite Infuser"] = {65014,45},
	["Royal Seal of King Llane"] = 65012,
	["Defender's Code"] = 60286,
	["Dying Curse"] = 60494,
	["Fury of the Five Flights"] = 60314,
	["Grim Toll"] = {60437,45},
	["Illustration of the Dragon Soul"] = 60486,
	["Rune of Repulsion"] = 60258,
	["Abyssal Rune"] = {67669,45},
	["Ancient Pickled Egg"] = {60062,45},
	["Banner of Victory"] = {67671,45},
	["Brawler's Souvenir"] = 68443,
	["Coren's Chromium Coaster"] = {60065,45},
	["Mirror of Truth"] = {60065,45},
	["Embrace of the Spider"] = {60492,45},
	["Je'Tze's Bell"] = {49623,45},
	["Loatheb's Shadow"] = 60439,
	["Majestic Dragon Figurine"] = 60525,
	["Mithril Pocketwatch"] = {60064,45},
	["Sundial of the Exiled"] = {60064,45},
	["Repelling Charge"] = 60180,
	["Spirit-World Glass"] = 60527,
	["Tears of Bitter Anguish"] = {58904,45},
	["The Black Heart"] = {67631,45},
	["The Egg of Mortal Essence"] = {60062,45},
	["Valor Medal of the First War"] = 60054,
}